@@ -18,7 +18,7 @@ from ..estimation import KaplanMeierFitter, NelsonAalenFitter, AalenAdditiveFitt
 from ..statistics import logrank_test, multivariate_logrank_test, pairwise_logrank_test
 from ..generate_datasets import *
 from ..plotting import plot_lifetimes
-from ..utils import datetimes_to_durations, survival_events_from_table, survival_table_from_events,StatError
+from ..utils import *
 from ..datasets import lcd_dataset
 
 class MiscTests(unittest.TestCase):
@@ -91,6 +91,20 @@ class MiscTests(unittest.TestCase):
         npt.assert_array_equal(T, T_)
         npt.assert_array_equal(C, C_)
 
+    def test_ci_labels(self):
+        naf = NelsonAalenFitter()
+        expected = ['upper', 'lower']
+        naf.fit(LIFETIMES, ci_labels=expected)
+        npt.assert_array_equal(naf.confidence_interval_.columns, expected)
+        kmf = KaplanMeierFitter()
+        kmf.fit(LIFETIMES, ci_labels=expected)
+        npt.assert_array_equal(kmf.confidence_interval_.columns, expected)
+
+    def test_group_survival_table_from_events_works_with_series(self):
+        df = pd.DataFrame([[1,True,3],[1,True,3],[4,False,2]], columns = ['T', 'E', 'G'])
+        ug,_,_,_ = group_survival_table_from_events(df.G, df.T, df.E, [0,0,0])
+        npt.assert_array_equal(ug, np.array([3,2]))
+
 
 class StatisticalTests(unittest.TestCase):
 
@@ -684,7 +698,6 @@ class PlottingTests(unittest.TestCase):
         return
 
 
-
 # some data
 LIFETIMES = np.array([2, 4, 4, 4, 5, 7, 10, 11, 11, 12])
 OBSERVED = np.array([1, 1, 0, 1, 0, 1, 1, 1, 1, 0])
